﻿using Syncfusion.HtmlConverter;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Graphics;
using Syncfusion.Pdf.Parsing;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace DifferentHeaderFooter_HTMLtoPDF
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            PdfDocument newDoc = new PdfDocument();
            newDoc.PageSettings.Size = PdfPageSize.A4;
            newDoc.PageSettings.SetMargins(0);

            PdfPageTemplateElement header = AddHeader(newDoc, "../../Header and Footer Template.html");
            PdfPageTemplateElement footer = AddFooter(newDoc, "../../Header and Footer Template.html");


            HtmlToPdfConverter htmlConverter = new HtmlToPdfConverter(HtmlRenderingEngine.WebKit);

            WebKitConverterSettings webKitSettings = new WebKitConverterSettings();           

            //Set the page height without header and footer height
            webKitSettings.PdfPageSize = new SizeF(PdfPageSize.A4.Width, PdfPageSize.A4.Height - header.Height - footer.Height);

            webKitSettings.AdditionalDelay = 1000;
            webKitSettings.Orientation = PdfPageOrientation.Landscape;
            //Set webkitpath
            webKitSettings.WebKitPath = @"D:\Source\HTMLConverter\Base\HTMLConverter.Base\Extensions\Syncfusion.QtWrapper\QtBinaries";
                        
            htmlConverter.ConverterSettings = webKitSettings;
            
            //Convert url to pdf
            PdfDocument document = htmlConverter.Convert("www.google.com");

            //Save and close the document.
            Stream stream = new MemoryStream();
            document.Save(stream);
            document.Close();

            //load the stream to PdfLoadedDocument
            PdfLoadedDocument ldoc = new PdfLoadedDocument(stream);

            //get each page and add header/footer using section
            for (int i = 0; i < ldoc.Pages.Count; i++)
            {
                PdfLoadedPage loadedPage = ldoc.Pages[i] as PdfLoadedPage;
                PdfTemplate template = loadedPage.CreateTemplate();
                PdfSection section = newDoc.Sections.Add();
                PdfPage page = section.Pages.Add();                
                PdfGraphics graphics = page.Graphics;
                if (i == 0)
                {

                    section.Template.Top = header;
                    section.Template.Bottom = footer;                  
                }
                else
                {
                    section.Template.Top = AddHeader(newDoc, "www.google.com");
                    section.Template.Bottom = AddFooter(newDoc, "www.google.com");
                }

                //Draw the template to the new document
                graphics.DrawPdfTemplate(template, new PointF(0, header.Height), new SizeF(page.Size.Width, page.Size.Height - header.Height - footer.Height));
            }

            //save and close the document
            newDoc.Save("Output.pdf");
            newDoc.Close();
            stream.Dispose();
            //Message box confirmation to view the created PDF document.
            if (MessageBox.Show("Do you want to view the PDF file?", "PDF File Created",
                MessageBoxButtons.YesNo, MessageBoxIcon.Information)
                == DialogResult.Yes)
            {
                //Launching the PDF file using the default Application.[Acrobat Reader]
                System.Diagnostics.Process.Start("Output.pdf");
                this.Close();
            }
            else
            {
                // Exit
                this.Close();
            }
        }

        /// <summary>
        /// Draws header to the document.
        /// </summary>
        private PdfPageTemplateElement AddHeader(PdfDocument doc, string url)
        {
            RectangleF rect = new RectangleF(0, 0, doc.PageSettings.Width, 100);

            //Create page template
            PdfPageTemplateElement header = new PdfPageTemplateElement(rect);
            HtmlToPdfConverter htmlConverter = new HtmlToPdfConverter(HtmlRenderingEngine.WebKit);
            WebKitConverterSettings webKitSettings = new WebKitConverterSettings();

            //Set the page height of header height
            webKitSettings.PdfPageSize = new SizeF(PdfPageSize.A4.Width,100);
            webKitSettings.Orientation = PdfPageOrientation.Landscape;

            webKitSettings.AdditionalDelay = 1000;

            //Set webkitpath
            webKitSettings.WebKitPath = @"D:\Source\HTMLConverter\Base\HTMLConverter.Base\Extensions\Syncfusion.QtWrapper\QtBinaries";

            htmlConverter.ConverterSettings = webKitSettings;

            //Convert url to pdf
            PdfDocument document = htmlConverter.Convert(url);
            document.Save("1.pdf");
            MemoryStream stream=new MemoryStream();
            document.Save(stream);
            PdfLoadedDocument ldoc = new PdfLoadedDocument(stream);
            PdfLoadedPage page = ldoc.Pages[0] as PdfLoadedPage;

            PdfTemplate template = page.CreateTemplate();

            header.Graphics.DrawPdfTemplate(template,new PointF(0,0));

            //Add header template at the top.
            return header;

        }

        /// <summary>
        /// Draws footer to the document.
        /// </summary>
        private PdfPageTemplateElement AddFooter(PdfDocument doc, string url)
        {
            RectangleF rect = new RectangleF(0, 0, doc.PageSettings.Width, 100);

            //Create page template
            PdfPageTemplateElement footer = new PdfPageTemplateElement(rect);
            HtmlToPdfConverter htmlConverter = new HtmlToPdfConverter(HtmlRenderingEngine.WebKit);
            WebKitConverterSettings webKitSettings = new WebKitConverterSettings();

            //Set the page height of header height
            webKitSettings.PdfPageSize = new SizeF(PdfPageSize.A4.Width, 100);
            webKitSettings.Orientation = PdfPageOrientation.Landscape;

            webKitSettings.AdditionalDelay = 1000;

            //Set webkitpath
            webKitSettings.WebKitPath = @"D:\Source\HTMLConverter\Base\HTMLConverter.Base\Extensions\Syncfusion.QtWrapper\QtBinaries";

            htmlConverter.ConverterSettings = webKitSettings;

            //Convert url to pdf
            PdfDocument document = htmlConverter.Convert(url);
            document.Save("2.pdf");
            MemoryStream stream = new MemoryStream();
            document.Save(stream);
            PdfLoadedDocument ldoc = new PdfLoadedDocument(stream);
            PdfLoadedPage page = ldoc.Pages[0] as PdfLoadedPage;

            PdfTemplate template = page.CreateTemplate();

            footer.Graphics.DrawPdfTemplate(template, new PointF(0, 0));

            //Add header template at the top.
            return footer;
        }
        
    }
}
